==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/mixer/adapter/prometheus/ExplicitBucketsDefinitionFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.prometheus;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ExplicitBucketsDefinitionFluentImpl<A extends ExplicitBucketsDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ExplicitBucketsDefinitionFluent<A>{

    private ExplicitBuilder explicitBuckets;

    public ExplicitBucketsDefinitionFluentImpl(){
    }
    public ExplicitBucketsDefinitionFluentImpl(ExplicitBucketsDefinition instance){
            this.withExplicitBuckets(instance.getExplicitBuckets()); 
    }

    
/**
 * This method has been deprecated, please use method buildExplicitBuckets instead.
 * @return The buildable object.
 */
@Deprecated public Explicit getExplicitBuckets(){
            return this.explicitBuckets!=null?this.explicitBuckets.build():null;
    }

    public Explicit buildExplicitBuckets(){
            return this.explicitBuckets!=null?this.explicitBuckets.build():null;
    }

    public A withExplicitBuckets(Explicit explicitBuckets){
            _visitables.remove(this.explicitBuckets);
            if (explicitBuckets!=null){ this.explicitBuckets= new ExplicitBuilder(explicitBuckets); _visitables.add(this.explicitBuckets);} return (A) this;
    }

    public Boolean hasExplicitBuckets(){
            return this.explicitBuckets != null;
    }

    public ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<A> withNewExplicitBuckets(){
            return new ExplicitBucketsNestedImpl();
    }

    public ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<A> withNewExplicitBucketsLike(Explicit item){
            return new ExplicitBucketsNestedImpl(item);
    }

    public ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<A> editExplicitBuckets(){
            return withNewExplicitBucketsLike(getExplicitBuckets());
    }

    public ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<A> editOrNewExplicitBuckets(){
            return withNewExplicitBucketsLike(getExplicitBuckets() != null ? getExplicitBuckets(): new ExplicitBuilder().build());
    }

    public ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<A> editOrNewExplicitBucketsLike(Explicit item){
            return withNewExplicitBucketsLike(getExplicitBuckets() != null ? getExplicitBuckets(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExplicitBucketsDefinitionFluentImpl that = (ExplicitBucketsDefinitionFluentImpl) o;
            if (explicitBuckets != null ? !explicitBuckets.equals(that.explicitBuckets) :that.explicitBuckets != null) return false;
            return true;
    }


    public class ExplicitBucketsNestedImpl<N> extends ExplicitFluentImpl<ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<N>> implements ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ExplicitBuilder builder;
    
            ExplicitBucketsNestedImpl(Explicit item){
                    this.builder = new ExplicitBuilder(this, item);
            }
            ExplicitBucketsNestedImpl(){
                    this.builder = new ExplicitBuilder(this);
            }
    
    public N and(){
            return (N) ExplicitBucketsDefinitionFluentImpl.this.withExplicitBuckets(builder.build());
    }
    public N endExplicitBuckets(){
            return and();
    }

}


}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/mixer/adapter/prometheus/ExplicitBucketsDefinitionFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.prometheus;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ExplicitBucketsDefinitionFluentImpl<A extends ExplicitBucketsDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ExplicitBucketsDefinitionFluent<A>{

    private ExplicitBuilder explicitBuckets;

    public ExplicitBucketsDefinitionFluentImpl(){
    }
    public ExplicitBucketsDefinitionFluentImpl(ExplicitBucketsDefinition instance){
            this.withExplicitBuckets(instance.getExplicitBuckets()); 
    }

    
/**
 * This method has been deprecated, please use method buildExplicitBuckets instead.
 * @return The buildable object.
 */
@Deprecated public Explicit getExplicitBuckets(){
            return this.explicitBuckets!=null?this.explicitBuckets.build():null;
    }

    public Explicit buildExplicitBuckets(){
            return this.explicitBuckets!=null?this.explicitBuckets.build():null;
    }

    public A withExplicitBuckets(Explicit explicitBuckets){
            _visitables.get("explicitBuckets").remove(this.explicitBuckets);
            if (explicitBuckets!=null){ this.explicitBuckets= new ExplicitBuilder(explicitBuckets); _visitables.get("explicitBuckets").add(this.explicitBuckets);} return (A) this;
    }

    public Boolean hasExplicitBuckets(){
            return this.explicitBuckets != null;
    }

    public ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<A> withNewExplicitBuckets(){
            return new ExplicitBucketsNestedImpl();
    }

    public ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<A> withNewExplicitBucketsLike(Explicit item){
            return new ExplicitBucketsNestedImpl(item);
    }

    public ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<A> editExplicitBuckets(){
            return withNewExplicitBucketsLike(getExplicitBuckets());
    }

    public ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<A> editOrNewExplicitBuckets(){
            return withNewExplicitBucketsLike(getExplicitBuckets() != null ? getExplicitBuckets(): new ExplicitBuilder().build());
    }

    public ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<A> editOrNewExplicitBucketsLike(Explicit item){
            return withNewExplicitBucketsLike(getExplicitBuckets() != null ? getExplicitBuckets(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ExplicitBucketsDefinitionFluentImpl that = (ExplicitBucketsDefinitionFluentImpl) o;
            if (explicitBuckets != null ? !explicitBuckets.equals(that.explicitBuckets) :that.explicitBuckets != null) return false;
            return true;
    }


    public class ExplicitBucketsNestedImpl<N> extends ExplicitFluentImpl<ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<N>> implements ExplicitBucketsDefinitionFluent.ExplicitBucketsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ExplicitBuilder builder;
    
            ExplicitBucketsNestedImpl(Explicit item){
                    this.builder = new ExplicitBuilder(this, item);
            }
            ExplicitBucketsNestedImpl(){
                    this.builder = new ExplicitBuilder(this);
            }
    
    public N and(){
            return (N) ExplicitBucketsDefinitionFluentImpl.this.withExplicitBuckets(builder.build());
    }
    public N endExplicitBuckets(){
            return and();
    }

}


}
